<?php
/**
 *	Adding an editor for the Venues post type.
 *
 *	@package		Builder Block Events
 *	@subpackage		Editor
 *	@author			Justin Kopepasah
 *	@since			1.0.0
 *
*/

if ( ! class_exists( 'BB_Events_Venue_Editor' ) ) {
	
	class BB_Events_Venue_Editor {
		private $options = array();
		private $page_ref = null;
		private $self_link = null;
		private $tabs = array();
		private $active_tab = null;
		private $tabless_self_link = null;
		private $saved_data_message = '';
		private $required_input_error_message = '';
		private $errors = array();
		private $messages = array();
		
		var $_post_type = 'it_bb_event_venue';
		
		public function __construct() {
			add_action( 'admin_menu', array( $this, 'add_admin_pages' ) );
		}
		
		public function init() {
			it_classes_load( 'it-form.php' );
			it_classes_load( 'it-utility.php' );
			it_classes_load( 'it-file-utility.php' );
			
			$this->options = apply_filters( $this->_post_type . '_load_data', array() );
			
			$this->saved_data_message = __( 'Settings saved.' );
			$this->required_input_error_message = __( 'Ensure that all of the required inputs are filled.', 'it-l10n-builder-block-events' );
			
			$this->tabs = array(
				'settings'      => __( 'Settings', 'it-l10n-builder-block-events' ),
				//'help' => __( 'How To', 'it-l10n-builder-block-events' ),
			);
			
			$this->active_tab = ( ! empty( $_REQUEST['editor_tab'] ) ) ? $_REQUEST['editor_tab'] : key( $this->tabs );
			
			$this->tabless_self_link = array_shift( explode( '?', $_SERVER['REQUEST_URI'] ) ) . '?post_type=' . $this->_post_type . '&page=' . $_REQUEST['page'];
			$this->self_link = $this->tabless_self_link;
			
			if ( $this->active_tab != key( $this->tabs ) )
				$this->self_link .= '&editor_tab=' . urlencode( $this->active_tab );
			
			$this->plugin_url = ITFileUtility::get_url_from_file( dirname( __FILE__ ) );
		}
		
		public function add_admin_pages() {
			$this->_page_ref = add_submenu_page( "edit.php?post_type={$this->_post_type}", 'Settings', 'Settings', 'edit_themes', 'bb-events-venue-editor', array( $this, 'index' ) );
			
			add_action( "load-{$this->_page_ref}", array( $this, 'init' ) );
			add_action( "admin_print_scripts-{$this->_page_ref}", array( $this, 'add_scripts' ) );
			add_action( "admin_print_styles-{$this->_page_ref}", array( $this, 'add_styles' ) );			
		}
		
		public function add_scripts() {
			$params = array(
				'required_input_error_string' => $this->required_input_error_message,
			);
			
			wp_enqueue_script( 'it-bb-events-script', "{$this->plugin_url}/js/editor.js" );
			wp_localize_script( 'it-bb-events-script', 'BB_Events_Venue_Editor', $params );
			
			ITUtility::add_tooltip_scripts();
		}
		
		public function add_styles() {
			wp_enqueue_style( 'it-bb-events-style', "{$this->plugin_url}/css/editor.css" );
			ITUtility::add_tooltip_styles();
		}
		
		public function index() {
			if ( 'help' == $this->active_tab ) {
				if ( ! empty( $_POST['save'] ) )
					$this->help_save_data();
				else
					$this->help_index();
			}
			else {
				if( ! empty( $_POST['save'] ) )
					$this->settings_save_data();
				else
					$this->settings_index();
			}
		}
		
		public function settings_save_data() {
			ITForm::check_nonce( 'save-primary' );
			
			$data = ITForm::get_post_data();
			
			$required_inputs = array( 
				$this->_post_type . '_name', 
				$this->_post_type . '_name_plural',
			);
			$has_errors = false;
			
			foreach ( $required_inputs as $var ) {
				if ( empty( $data[$var] ) ) {
					ITUtility::show_error_message( $this->required_input_error_message );
					$has_errors = true;
					break;
				}
			}
			
			
			// Add in any validation checks here. Such as ensuring that an input that stores a number
			// contains just a number. Show errors for any issues.
			if ( $has_errors ) {
				$this->settings_index( $data );
				return;
			}
			
			$this->options = ITUtility::merge_defaults( $data, $this->options );
			
			do_action( $this->_post_type . '_save_data', $this->options );
			ITUtility::show_status_message( $this->saved_data_message );
			
			$this->settings_index();
		}
		
		public function settings_index( $options = null ) {
			if ( ! is_array( $options ) ) {
				$options = $this->options;
			}
			
			$form =& new ITForm( $options );
			
			?>
				<div class="wrap">
					<?php $form->start_form( array( 'class' => 'validate' ), 'save-primary' ); ?>
						<?php screen_icon( $screen = $this->_post_type . '_settings' ); ?>
						<h2><?php _e( 'Settings', 'it-l10n-builder-block-events' ); ?></h2>
						
						<div class="divider-wrap first">
							<h3><?php _e( 'Post type name and name plural', 'it-l10n-builder-block-events' ); ?></h3>
							<p><?php _e( 'If you want to change the name and plural name of your the post type, you can do so here.', 'it-l10n-builder-block-events' ); ?></p>
							<table class="form-table">
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_name"><?php _e( 'Name', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(required)' ); ?></span></label></th>
									<td><?php $form->add_text_box( $this->_post_type . '_name' ); ?></td>
								</tr>
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_name_plural"><?php _e( 'Plural Name', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(required)' ); ?></span></label></th>
									<td><?php $form->add_text_box( $this->_post_type . '_name_plural' ); ?></td>
								</tr>
							</table>
						</div>
												
						<p class="submit">
							<?php $form->add_submit( 'save', array( 'value' => __( 'Save Changes' ), 'class' => 'button-primary' ) ); ?>
						</p>
					<?php $form->end_form(); ?>
				</div>
			<?php
			
		}
		
		public function help_save_data() {
			
		}
		
		public function help_index() {
		
		
		}
		
		public function print_tabs() {
			echo "<h2 class='nav-tab-wrapper'>";
			
			foreach ( (array) $this->tabs as $var => $name ) {
				$link = $this->tabless_self_link;
				if ( $var != key( $this->tabs ) )
					$link .= '&editor_tab=' . urlencode( $var );
				
				$class = 'nav-tab' . ( ( $var === $this->active_tab ) ? ' nav-tab-active' : '' );
				
				echo "<a class='$class' href='$link'>$name</a>";
			}
			
			echo "</h2>\n";
		}
	}
	
	new BB_Events_Venue_Editor();
}