<?php
/**
 *	Register the venues post type.
 *
 *	@package		Builder Block Events
 *	@subpackage		Post Types
 *	@author			Justin Kopepasah
 *	@since			1.0.0
 *
*/

if ( ! class_exists( 'BB_Events_Venues' ) ) {
	it_classes_load( 'it-post-type.php' );
	
	class BB_Events_Venues extends ITPostType {
		var $_file = __FILE__;
		
		var $_var = 'it_bb_event_venue';
		var $_name = 'Venue';
		var $_name_plural = 'Venues';
		
		var $_settings = array(
			'supports'	  		  => array( 'title' ),
			'menu_icon'   		  => 'images/venue-icon-inactive.png',
			'publicly_queryable'  => false,
			'exclude_from_search' => true,
			'show_in_nav_menus'	  => false,
		);
		
		var $_meta_boxes = array(
			'map'		=> array(
				'title'		=> 'Location',
				'callback'	=> 'render_meta_box_map',
				'context'	=> 'normal',
				'priority'	=> 'default',
			),
			'viewable'		=> array(
				'title'		=> 'Note',
				'callback'	=> 'render_meta_box_viewable',
				'context'	=> 'side',
				'priority'	=> 'default',
			),
		);
		
		var $_editor_load_jquery = true;
		var $_public_load_jquery = true;
		var $_has_custom_screen_icon = true;
		
		function _load() {
			parent::_load();
			
			$it_bb_event_settings = apply_filters( $this->_var . '_load_data', array() );
			$this->_name = $it_bb_event_settings[$this->_var . '_name'];
			$this->_name_plural = $it_bb_event_settings[$this->_var . '_name_plural'];
			
		}
		
		function admin_print_scripts() {
			wp_enqueue_script( 'google-maps-api', 'http://maps.google.com/maps/api/js?sensor=false', array(), null );
		}
		
		function print_scripts() {
			$this->admin_print_scripts();
		}
		
		function validate_meta_box_options( $options ) {
			return $options;
		}
		
		// Event map meta box.
		function render_meta_box_map( $post, $form, $options ) {
			
			$settings = apply_filters( $this->_var . '_load_data', array() );
			
			$event_editor = new BB_Events_Editor();
			$event_settings = apply_filters( $event_editor->_post_type . '_load_data', array() );
			
		?>
			<div class="event-address-wrapper">
				<p><?php _e( 'Enter the address here as you want it to display on the ' . strtolower( $event_settings[$event_editor->_post_type . '_name'] ) . '. This address will not be used to find directions the ' . strtolower( $event_settings[$event_editor->_post_type . '_name'] ) . '. Use the <strong>Map</strong> (below) for allowing users to get directions.', 'it-l10n-builder-block-events' ); ?></p>
				<div class="event-address">
					<div class="address-textarea">
						<p><?php $form->add_text_area( 'event_address', array( 'style' => 'width: 400px;min-height:100px;' ) ); ?></p>
					</div>
					<div class="address-sample">
						<p><strong><?php _e( 'Example Address:', 'it-l10n-builder-block-events' ); ?></strong></p>
						<p><?php _e( 'The White House', 'it-l10n-builder-block-events' ); ?></p>
						<p><?php _e( '1600 Pennsylvania Avenue NW', 'it-l10n-builder-block-events' ); ?></p>
						<p><?php _e( 'Washington, DC 20500', 'it-l10n-builder-block-events' ); ?></p>
					</div>
				</div>
			</div>
			<hr/>
			<p><?php _e( 'This map is used for displaying the exact location of your ' . strtolower( $event_settings[$event_editor->_post_type . '_name'] ) . ' and allowing users to find directions to this location by entering their current location on the ' . strtolower( $event_settings[$event_editor->_post_type . '_name'] ) . ' page.', 'it-l10n-builder-block-events' ); ?></p>
			
			<p><?php _e( 'Set up the map as you would like it to appear on your site. The location marker can be positioned by dragging it or clicking on a new location on the map.', 'it-l10n-builder-block-events' ); ?></p>
			
			<p><?php _e( 'To simplify finding your location quickly, type a search term(s) in the box below and click the search button. For example, if your event is in Oklahoma City, type "Oklahoma City" in the search field. This term <strong>will not</strong> be used on the site, it is merely used to pinpoint your location faster. To display an address on your site, enter it in the <strong>Address</strong> area above.', 'it-l10n-builder-block-events' ); ?></p>
			<p><?php $form->add_text_box( 'search_address', array( 'placeholder' => 'Enter search terms...', 'style' => 'width: 300px;' ) ); ?><?php $form->add_button( 'locate_search_address_on_map', array( 'value' => 'Search', 'class' => 'button' ) ); ?></p>
			
			<div style="overflow:auto;">
				<div id="map_canvas" style="width:100%; height:400px"></div>
			</div>
			
			<input type="hidden" id="map_center_latitude" name="map_center_latitude" value="<?php echo $options['marker_latitude']; ?>" />
			<input type="hidden" id="map_center_longitude" name="map_center_longitude" value="<?php echo $options['marker_longitude']; ?>" />
			<?php $form->add_hidden( 'map_type' ); ?>
			<?php $form->add_hidden( 'map_zoom' ); ?>
			<?php $form->add_hidden( 'marker_latitude' ); ?>
			<?php $form->add_hidden( 'marker_longitude' ); ?>
			
		<?php
		} // End map meta box.
		
		// Event map meta box.
		function render_meta_box_viewable( $post, $form, $options ) {
		?>
			<div class="viewable-note">
				<p><?php _e( 'This ' . $this->_name . ' (like all other ' . $this->_name_plural . ') is not viewable by the public. After publishing this ' . $this->_name . ' you can select to use it under the <strong>Location</strong> meta box when adding or editing an Event.', 'it-l10n-builder-block-events' ); ?></p>
				<p><img src="<?php echo ITFileUtility::get_url_from_file( dirname( $this->_file ) ); ?>/images/using-venues.png" alt="" /></p>
			</div>
		<?php	
		}
		
	}
	new BB_Events_Venues();
}